@@ -14,15 +14,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import absolute_import, division, print_function
-
 import os
 from messente.api.sms.api.error import ConfigurationError
 from messente.api.sms.logging import log
 
-from six.moves import configparser
+import configparser
 
-configuration = configparser.SafeConfigParser()
+configuration = configparser.ConfigParser()
 
 configuration.add_section("api")
 configuration.add_section("sms")
