@@ -2,13 +2,10 @@
 
 import responses
 
+from messente.api.sms.api import Response
+from messente.api.sms.api import credit
 from test import utils
 
-from messente.api import credit
-from messente.api import Response
-from messente.api.error import ConfigurationError
-
-
 api = credit.CreditAPI(
     user="test",
     password="test",
